Python RFlink library
=====================

.. image:: https://travis-ci.org/aequitas/python-rflink.svg?branch=master
    :target: https://travis-ci.org/aequitas/python-rflink

.. image:: https://img.shields.io/pypi/v/rflink.svg
    :target: https://pypi.python.org/pypi/rflink

Library and CLI tools for interacting with RFlink 433MHz transceiver.

http://www.nemcon.nl/blog2/
